@@ -27,14 +27,15 @@
 #include "akregator_options.h"
 
 #include <kcmdlineargs.h>
+#include <KDebug>
 #include <klocale.h>
-#include <libkdepim/pimapplication.h>
+#include <kontactinterface/pimuniqueapplication.h>
 #include <QtDBus/QtDBus>
 #include <QStringList>
 
 namespace Akregator {
 
-class Application : public KPIM::PimApplication {
+class Application : public KontactInterface::PimUniqueApplication {
   public:
     Application() : mMainWindow(0) {}
     ~Application() {}
@@ -49,7 +50,7 @@ int Application::newInstance()
 {
   if (!isSessionRestored())
   {
-    QDBusInterface akr("org.kde.akregator", "/Akregator", "org.kde.akregator.part");
+    QDBusInterface akr(QLatin1String("org.kde.akregator"), QLatin1String("/Akregator"), QLatin1String("org.kde.akregator.part"));
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -59,28 +60,10 @@ int Application::newInstance()
       mMainWindow->setupProgressWidgets();
       if (!args->isSet("hide-mainwindow"))
         mMainWindow->show();
-      akr.call( "openStandardFeedList");
+      akr.call( QLatin1String("openStandardFeedList"));
     }
 
-    QString addFeedGroup = !args->getOption("group").isEmpty() ?
-         args->getOption("group")
-         : i18n("Imported Folder");
-
-    QStringList feeds = args->getOptionList("addfeed");
-    QStringList feedsToAdd;
-    QStringList::ConstIterator end( feeds.constEnd() );
-    for (QStringList::ConstIterator it = feeds.constBegin(); it != end; ++it)
-        feedsToAdd.append(*it);
-
-    if (feedsToAdd.isEmpty() && args->count() > 0) {
-        QString url = args->url(0).url();
-        if(!url.isEmpty())
-            feedsToAdd.append(url);
-    }
-
-    if (!feedsToAdd.isEmpty())
-        akr.call("addFeedsToGroup", feedsToAdd, addFeedGroup );
-
+    akr.call( QLatin1String("handleCommandLine") );
     args->clear();
   }
   return KUniqueApplication::newInstance();
@@ -95,6 +78,11 @@ int main(int argc, char **argv)
     KCmdLineArgs::addCmdLineOptions( Akregator::akregator_options() );
     KUniqueApplication::addCmdLineOptions();
 
+    if ( !Akregator::Application::start() ) {
+        kWarning() << "akregator is already running, exiting.";
+        exit( 0 );
+    }
+
     Akregator::Application app;
 
     // start knotifyclient if not already started. makes it work for people who doesn't use full kde, according to kmail devels
