@@ -23,15 +23,17 @@
 */
 
 #include "entriescountdialog.h"
-#include <kdebug.h>
 #include "settings.h"
 
+#include <kdebug.h>
+
+
 EntriesCountDialog::EntriesCountDialog( QWidget *parent )
-        : KDialog( parent )
+    : KDialog( parent )
 {
-    QWidget *dialog = new QWidget;
-    ui.setupUi( dialog );
-    this->setMainWidget( dialog );
+    QWidget *widget = new QWidget;
+    ui.setupUi( widget );
+    setMainWidget( widget );
     ui.spinCount->setValue(Settings::updateEntriesCount());
 }
 
