@@ -23,10 +23,13 @@
 
 namespace Grammar {
 class GrammarLoaderPrivate;
+class GrammarSettings;
 class GRAMMAR_EXPORT GrammarLoader : public QObject
 {
     Q_OBJECT
 public:
+    static GrammarLoader *openGrammarLoader();
+
     GrammarLoader();
     ~GrammarLoader();
 
@@ -34,6 +37,12 @@ public:
 
     QStringList languages() const;
 
+    GrammarSettings *settings() const;
+
+Q_SIGNALS:
+    void configurationChanged();
+
+
 private:
     friend class GrammarLoaderPrivate;
     GrammarLoaderPrivate * const d;
