@@ -33,19 +33,22 @@
 #include "stylepage.h"
 
 // including the styles
-#include "detailledstyle.h"
-#include "mikesstyle.h"
-#include "ringbinderstyle.h"
-#include "compactstyle.h"
+#include "detailled/detailledstyle.h"
+#include "mike/mikesstyle.h"
+#include "ringbinder/ringbinderstyle.h"
+#include "compact/compactstyle.h"
+#include "printing/grantlee/grantleeprintstyle.h"
 
 #include <KApplication>
 #include <KDebug>
 #include <KDialog>
 #include <KGlobal>
 #include <KLocale>
+#include <KStandardDirs>
 
 #include <QPushButton>
 #include <QPrinter>
+#include <QDirIterator>
 
 using namespace KABPrinting;
 
@@ -78,10 +81,28 @@ PrintingWizard::PrintingWizard( QPrinter *printer, QItemSelectionModel *selectio
   mStylePage->setSortOrder( Settings::self()->sortOrder() == 0 ?
                               Qt::AscendingOrder :
                               Qt::DescendingOrder );
+  readConfig();
 }
 
 PrintingWizard::~PrintingWizard()
 {
+    writeConfig();
+}
+
+void PrintingWizard::readConfig()
+{
+    KConfigGroup grp( KGlobal::config(), "PrintingWizard" );
+    const QSize size = grp.readEntry( "Size", QSize(300, 200) );
+    if ( size.isValid() ) {
+        resize( size );
+    }
+}
+
+void PrintingWizard::writeConfig()
+{
+    KConfigGroup grp( KGlobal::config(), "PrintingWizard" );
+    grp.writeEntry( "Size", size() );
+    grp.sync();
 }
 
 void PrintingWizard::setDefaultAddressBook( const Akonadi::Collection &addressBook )
@@ -96,6 +117,47 @@ void PrintingWizard::accept()
   setResult(QDialog::Accepted);
 }
 
+void PrintingWizard::loadGrantleeStyle()
+{
+    const QString relativePath = QLatin1String("kaddressbook/printing/themes/");
+    QStringList themesDirectories = KGlobal::dirs()->findDirs("data", relativePath);
+    if (themesDirectories.count() < 2) {
+        //Make sure to add local directory
+        const QString localDirectory = KStandardDirs::locateLocal("data", relativePath);
+        if (!themesDirectories.contains(localDirectory)) {
+            themesDirectories.append(localDirectory);
+        }
+    }
+
+    Q_FOREACH (const QString &directory, themesDirectories) {
+        QDirIterator dirIt( directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot );
+        QStringList alreadyLoadedThemeName;
+        while ( dirIt.hasNext() ) {
+            dirIt.next();
+            const QString themeInfoFile = dirIt.filePath() + QDir::separator() + QLatin1String("theme.desktop");
+            KConfig config( themeInfoFile );
+            KConfigGroup group( &config, QLatin1String( "Desktop Entry" ) );
+            QString name = group.readEntry( "Name", QString() );
+            if (name.isEmpty()) {
+                continue;
+            }
+            if (alreadyLoadedThemeName.contains(name)) {
+                int i = 2;
+                const QString originalName(name);
+                while (alreadyLoadedThemeName.contains(name)) {
+                    name = originalName + QString::fromLatin1(" (%1)").arg(i);
+                    ++i;
+                }
+            }
+            const QString printThemePath(dirIt.filePath() + QDir::separator());
+            if (!printThemePath.isEmpty()) {
+                alreadyLoadedThemeName << name;
+                mStyleFactories.append( new GrantleeStyleFactory(name, printThemePath, this) );
+            }
+        }
+    }
+}
+
 void PrintingWizard::registerStyles()
 {
   mStyleFactories.append( new DetailledPrintStyleFactory( this ) );
@@ -103,6 +165,8 @@ void PrintingWizard::registerStyles()
   mStyleFactories.append( new RingBinderPrintStyleFactory( this ) );
   mStyleFactories.append( new CompactStyleFactory( this ) );
 
+  loadGrantleeStyle();
+
   mStylePage->clearStyleNames();
   for ( int i = 0; i < mStyleFactories.count(); ++i ) {
     mStylePage->addStyleName( mStyleFactories.at( i )->description() );
