@@ -21,7 +21,7 @@
 
 #include "pimcommon/widgets/renamefiledialog.h"
 
-#include <Akonadi/Contact/ContactViewer>
+#include <kaddressbookgrantlee/widget/grantleecontactviewer.h>
 
 #ifdef QGPGME_FOUND
 #include <gpgme++/context.h>
@@ -41,6 +41,7 @@
 #include <KPushButton>
 #include <KTemporaryFile>
 #include <KUrl>
+#include <KStandardGuiItem>
 #include <KIO/NetAccess>
 
 #include <QtCore/QFile>
@@ -55,22 +56,26 @@
 
 class VCardViewerDialog : public KDialog
 {
+    Q_OBJECT
   public:
     VCardViewerDialog( const KABC::Addressee::List &list,
                        QWidget *parent );
+    ~VCardViewerDialog();
 
     KABC::Addressee::List contacts() const;
 
-  protected:
+  protected Q_SLOTS:
     void slotYes();
     void slotNo();
     void slotApply();
     void slotCancel();
 
   private:
+    void readConfig();
+    void writeConfig();
     void updateView();
 
-    Akonadi::ContactViewer *mView;
+    KAddressBookGrantlee::GrantleeContactViewer *mView;
 
     KABC::Addressee::List mContacts;
     KABC::Addressee::List::Iterator mIt;
@@ -117,14 +122,14 @@ bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts ) const
   if ( list.count() == 1 ) {
     url = KFileDialog::getSaveUrl(
       QString( list[ 0 ].givenName() +
-               QLatin1Char( '_' ) +
+               QLatin1Char( QLatin1Char('_') ) +
                list[ 0 ].familyName() +
                QLatin1String( ".vcf" ) ) );
     if ( url.isEmpty() ) { // user canceled export
       return true;
     }
 
-    if ( option( "version" ) == "v21" ) {
+    if ( option( QLatin1String("version") ) == QLatin1String("v21") ) {
       ok = doExport( url, converter.exportVCards( list, KABC::VCardConverter::v2_1 ) );
     } else {
       ok = doExport( url, converter.exportVCards( list, KABC::VCardConverter::v3_0 ) );
@@ -151,11 +156,11 @@ bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts ) const
       for ( int i = 0; i < list.count(); ++i ) {
         const KABC::Addressee contact = list.at( i );
 
-        url = baseUrl.url() + '/' + contactFileName( contact ) + ".vcf";
+        url = baseUrl.url() + QLatin1Char('/') + contactFileName( contact ) + QLatin1String(".vcf");
 
         bool tmpOk = false;
 
-        if ( option( "version" ) == "v21" ) {
+        if ( option( QLatin1String("version") ) == QLatin1String("v21") ) {
           tmpOk = doExport( url, converter.exportVCard( contact, KABC::VCardConverter::v2_1 ) );
         } else {
           tmpOk = doExport( url, converter.exportVCard( contact, KABC::VCardConverter::v3_0 ) );
@@ -167,12 +172,12 @@ bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts ) const
     }
     case KMessageBox::Yes:
     {
-      url = KFileDialog::getSaveUrl( KUrl( "addressbook.vcf" ) );
+      url = KFileDialog::getSaveUrl( KUrl( QLatin1String("addressbook.vcf") ) );
       if ( url.isEmpty() ) {
         return true; // user canceled export
       }
 
-      if ( option( "version" ) == "v21" ) {
+      if ( option( QLatin1String("version") ) == QLatin1String("v21") ) {
         ok = doExport( url, converter.exportVCards( list, KABC::VCardConverter::v2_1 ) );
       } else {
         ok = doExport( url, converter.exportVCards( list, KABC::VCardConverter::v3_0 ) );
@@ -194,16 +199,16 @@ KABC::Addressee::List VCardXXPort::importContacts() const
   KABC::Addressee::List addrList;
   KUrl::List urls;
 
-  if ( !option( "importData" ).isEmpty() ) {
-    addrList = parseVCard( option( "importData" ).toUtf8() );
+  if ( !option( QLatin1String("importData") ).isEmpty() ) {
+    addrList = parseVCard( option( QLatin1String("importData") ).toUtf8() );
   } else {
-    if ( !option( "importUrl" ).isEmpty() ) {
-      urls.append( KUrl( option( "importUrl" ) ) );
+    if ( !option( QLatin1String("importUrl") ).isEmpty() ) {
+      urls.append( KUrl( option( QLatin1String("importUrl") ) ) );
     } else {
       urls =
         KFileDialog::getOpenUrls(
           KUrl(),
-          "*.vcf|vCards",
+          QLatin1String("*.vcf|vCards"),
           parentWidget(),
           i18nc( "@title:window", "Select vCard to Import" ) );
     }
@@ -252,7 +257,7 @@ KABC::Addressee::List VCardXXPort::importContacts() const
       }
     }
 
-    if ( !option( "importUrl" ).isEmpty() ) { // a vcard was passed via cmd
+    if ( !option( QLatin1String("importUrl") ).isEmpty() ) { // a vcard was passed via cmd
       if ( addrList.isEmpty() ) {
         if ( anyFailures && urls.count() > 1 ) {
           KMessageBox::information(
@@ -267,13 +272,13 @@ KABC::Addressee::List VCardXXPort::importContacts() const
         QPointer<VCardViewerDialog> dlg = new VCardViewerDialog( addrList, parentWidget() );
         if ( dlg->exec() && dlg ) {
           addrList = dlg->contacts();
+        } else {
+            addrList.clear();
         }
-
         delete dlg;
       }
     }
   }
-
   return addrList;
 }
 
@@ -288,9 +293,8 @@ bool VCardXXPort::doExport( const KUrl &url, const QByteArray &data ) const
 {   
     KUrl newUrl(url);
     if ( newUrl.isLocalFile() && QFileInfo( newUrl.toLocalFile() ).exists() ) {
-        PimCommon::RenameFileDialog::RenameFileDialogResult result = PimCommon::RenameFileDialog::RENAMEFILE_IGNORE;
         PimCommon::RenameFileDialog *dialog = new PimCommon::RenameFileDialog(newUrl, false, parentWidget());
-        result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
+        PimCommon::RenameFileDialog::RenameFileDialogResult result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
         if ( result == PimCommon::RenameFileDialog::RENAMEFILE_RENAME ) {
             newUrl = dialog->newName();
         } else if (result == PimCommon::RenameFileDialog::RENAMEFILE_IGNORE) {
@@ -332,20 +336,20 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
     addr.setFormattedName( (*it).formattedName() );
 
     bool addrDone = false;
-    if ( dlg->exportDisplayName() ) {		// output display name as N field
+    if ( dlg->exportDisplayName() ) {                // output display name as N field
       QString fmtName = (*it).formattedName();
-      QStringList splitNames = fmtName.split( ' ', QString::SkipEmptyParts );
+      QStringList splitNames = fmtName.split( QLatin1Char(' '), QString::SkipEmptyParts );
       if ( splitNames.count() >= 2 ) {
         addr.setPrefix( QString() );
         addr.setGivenName( splitNames.takeFirst() );
         addr.setFamilyName( splitNames.takeLast() );
-        addr.setAdditionalName( splitNames.join( " " ) );
+        addr.setAdditionalName( splitNames.join( QLatin1String(" ") ) );
         addr.setSuffix( QString() );
         addrDone = true;
       }
     }
 
-    if ( !addrDone ) {				// not wanted, or could not be split
+    if ( !addrDone ) {                                // not wanted, or could not be split
       addr.setPrefix( (*it).prefix() );
       addr.setGivenName( (*it).givenName() );
       addr.setAdditionalName( (*it).additionalName() );
@@ -447,8 +451,8 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
 void VCardXXPort::addKey( KABC::Addressee &addr, KABC::Key::Type type ) const
 {
 #ifdef QGPGME_FOUND
-  const QString fingerprint = addr.custom( "KADDRESSBOOK",
-                                           ( type == KABC::Key::PGP ? "OPENPGPFP" : "SMIMEFP" ) );
+  const QString fingerprint = addr.custom( QLatin1String("KADDRESSBOOK"),
+                                           ( type == KABC::Key::PGP ? QLatin1String("OPENPGPFP") : QLatin1String("SMIMEFP") ) );
   if ( fingerprint.isEmpty() ) {
     return;
   }
@@ -489,8 +493,10 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget
     mContacts( list )
 {
   setCaption( i18nc( "@title:window", "Import vCard" ) );
-  setButtons( Yes | No | Apply | Cancel );
-  setDefaultButton( Yes );
+  setButtons( User1 | User2 | Apply | Cancel );
+  setButtonGuiItem(User1, KStandardGuiItem::no());
+  setButtonGuiItem(User2, KStandardGuiItem::yes());
+  setDefaultButton( User1 );
   setModal( true );
   showButtonSeparator( true );
 
@@ -509,21 +515,45 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget
   label->setFont( font );
   layout->addWidget( label );
 
-  mView = new Akonadi::ContactViewer( page );
+  mView = new KAddressBookGrantlee::GrantleeContactViewer( page );
+
   layout->addWidget( mView );
 
   setButtonText( Apply, i18nc( "@action:button", "Import All..." ) );
 
   mIt = mContacts.begin();
 
-  connect( this, SIGNAL(yesClicked()), this, SLOT(slotYes()) );
-  connect( this, SIGNAL(noClicked()), this, SLOT(slotNo()) );
+  connect( this, SIGNAL(user2Clicked()), this, SLOT(slotYes()) );
+  connect( this, SIGNAL(user1Clicked()), this, SLOT(slotNo()) );
   connect( this, SIGNAL(applyClicked()), this, SLOT(slotApply()) );
   connect( this, SIGNAL(cancelClicked()), this, SLOT(slotCancel()) );
 
   updateView();
+  readConfig();
 }
 
+VCardViewerDialog::~VCardViewerDialog()
+{
+    writeConfig();
+}
+
+void VCardViewerDialog::readConfig()
+{
+    KConfigGroup group( KGlobal::config(), "VCardViewerDialog" );
+    const QSize size = group.readEntry( "Size", QSize(600, 400) );
+    if ( size.isValid() ) {
+        resize( size );
+    }
+}
+
+void VCardViewerDialog::writeConfig()
+{
+    KConfigGroup group( KGlobal::config(), "VCardViewerDialog" );
+    group.writeEntry( "Size", size() );
+    group.sync();
+}
+
+
 KABC::Addressee::List VCardViewerDialog::contacts() const
 {
   return mContacts;
@@ -543,6 +573,7 @@ void VCardViewerDialog::slotYes()
 
   if ( mIt == mContacts.end() ) {
     slotApply();
+    return;
   }
 
   updateView();
@@ -550,11 +581,14 @@ void VCardViewerDialog::slotYes()
 
 void VCardViewerDialog::slotNo()
 {
-  // remove the current contact from the result set
-  mIt = mContacts.erase( mIt );
-
+    if ( mIt == mContacts.end() ) {
+        accept();
+      return;
+    }
+    // remove the current contact from the result set
+    mIt = mContacts.erase( mIt );
   if ( mIt == mContacts.end() ) {
-    slotApply();
+    return;
   }
 
   updateView();
@@ -568,7 +602,7 @@ void VCardViewerDialog::slotApply()
 void VCardViewerDialog::slotCancel()
 {
   mContacts.clear();
-  KDialog::accept();
+  reject();
 }
 
 // ---------- VCardExportSelection Dialog ---------------- //
@@ -654,7 +688,7 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
            "name shown correctly in GMail or Android." ) );
   layout->addWidget( mDisplayNameBox, 5, 0, 1, 2 );
 
-  KConfig config( "kaddressbookrc" );
+  KConfig config( QLatin1String("kaddressbookrc") );
   const KConfigGroup group( &config, "XXPortVCard" );
 
   mPrivateBox->setChecked( group.readEntry( "ExportPrivateFields", true ) );
@@ -667,7 +701,7 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
 
 VCardExportSelectionDialog::~VCardExportSelectionDialog()
 {
-  KConfig config( "kaddressbookrc" );
+  KConfig config( QLatin1String("kaddressbookrc") );
   KConfigGroup group( &config, "XXPortVCard" );
 
   group.writeEntry( "ExportPrivateFields", mPrivateBox->isChecked() );
@@ -707,3 +741,4 @@ bool VCardExportSelectionDialog::exportDisplayName() const
 {
   return mDisplayNameBox->isChecked();
 }
+#include "vcard_xxport.moc"
