@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,14 +19,10 @@
 #define GRANTLEECONTACTUTILS_H
 
 #include "kaddressbook_grantlee_export.h"
-#include <QVariantHash>
 
-class KADDRESSBOOK_GRANTLEE_EXPORT GrantleeContactUtils
+namespace GrantleeContactUtils
 {
-public:
-    GrantleeContactUtils();
-    QString variableI18n(const QString &variable);
-    void insertVariableToQVariantHash(QVariantHash &contactI18n, const QString &variable);
-};
+KADDRESSBOOK_GRANTLEE_EXPORT QString variableI18n(const QString &variable);
+}
 
 #endif // GRANTLEECONTACTUTILS_H
