@@ -70,8 +70,8 @@
 #ifdef KMAIL_SUPPORTED
 #include "kmailinterface.h"
 
-static const char* KMAIL_DBUS_SERVICE = "org.kde.kmail";
-//static const char* KMAIL_DBUS_PATH    = "/KMail";
+static const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
+//static const QLatin1String KMAIL_DBUS_PATH("/KMail");
 #endif
 
 namespace HeaderParsing
@@ -154,7 +154,7 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
         return -1;
     }
     jobdata.bcc  = (jobdata.event.emailBcc() ? Preferences::emailBccAddress() : QString());
-    kDebug() << "To:" << jobdata.event.emailAddresses(",")
+    kDebug() << "To:" << jobdata.event.emailAddresses(QLatin1String(","))
                   << endl << "Subject:" << jobdata.event.emailSubject();
 
     MailTransport::TransportManager* manager = MailTransport::TransportManager::self();
@@ -217,7 +217,7 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
     // MessageQueueJob email addresses must be pure, i.e. without display name. Note
     // that display names are included in the actual headers set up by initHeaders().
     mailjob->addressAttribute().setFrom(extractEmailAndNormalize(jobdata.from));
-    mailjob->addressAttribute().setTo(extractEmailsAndNormalize(jobdata.event.emailAddresses(",")));
+    mailjob->addressAttribute().setTo(extractEmailsAndNormalize(jobdata.event.emailAddresses(QLatin1String(","))));
     if (!jobdata.bcc.isEmpty())
         mailjob->addressAttribute().setBcc(extractEmailsAndNormalize(jobdata.bcc));
     MailTransport::SentBehaviourAttribute::SentBehaviour sentAction =
@@ -315,11 +315,11 @@ void initHeaders(KMime::Message& message, KAMail::JobData& data)
     message.setHeader(subject);
 
     KMime::Headers::UserAgent* agent = new KMime::Headers::UserAgent;
-    agent->fromUnicodeString(KGlobal::mainComponent().aboutData()->programName() + "/" KALARM_VERSION, "us-ascii");
+    agent->fromUnicodeString(KGlobal::mainComponent().aboutData()->programName() + QLatin1String("/" KALARM_VERSION), "us-ascii");
     message.setHeader(agent);
 
     KMime::Headers::MessageID* id = new KMime::Headers::MessageID;
-    id->generate(data.from.mid(data.from.indexOf('@') + 1).toLatin1());
+    id->generate(data.from.mid(data.from.indexOf(QLatin1Char('@')) + 1).toLatin1());
     message.setHeader(id);
 }
 
@@ -365,7 +365,7 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
         // Append each attachment in turn
         for (QStringList::Iterator at = attachments.begin();  at != attachments.end();  ++at)
         {
-            QString attachment = (*at).toLocal8Bit();
+            QString attachment = QString::fromLatin1((*at).toLocal8Bit());
             KUrl url(attachment);
             QString attachError = i18nc("@info", "Error attaching file: <filename>%1</filename>", attachment);
             url.cleanPath();
@@ -725,7 +725,7 @@ const QTextCodec* codecForName(const QByteArray& str)
         return 0;
     QByteArray codec = str;
     kAsciiToLower(codec.data());
-    return KGlobal::charsets()->codecForName(codec);
+    return KGlobal::charsets()->codecForName(QLatin1String(codec));
 }
 
 /******************************************************************************
@@ -832,7 +832,7 @@ KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalid
             {
                 int len = endName - start;
                 QString name = text.mid(start, endName - start);
-                if (name[0] == '"'  &&  name[len - 1] == '"')
+                if (name[0] == QLatin1Char('"')  &&  name[len - 1] == QLatin1Char('"'))
                     name = name.mid(1, len - 2);
                 mbox.setName(name);
             }
