@@ -201,7 +201,7 @@ private:
         q->bringToForeground( dlg );
         if ( !errors.empty() )
             q->setLastError( gpg_error( GPG_ERR_GENERAL ),
-                             errors.join( "\n" ) );
+                             errors.join( QLatin1String("\n") ) );
         q->emitDoneOrError();
     }
     void slotProgress( int current, int total, const QString & what ) {
@@ -380,7 +380,7 @@ static std::vector<File> parse_sum_file( const QString & fileName ) {
     QFile f( fileName );
     if ( f.open( QIODevice::ReadOnly ) ) {
         QTextStream s( &f );
-        QRegExp rx( "(\\?)([a-f0-9A-F]+) ([ *])([^\n]+)\n*" );
+        QRegExp rx( QLatin1String("(\\?)([a-f0-9A-F]+) ([ *])([^\n]+)\n*") );
         while ( !s.atEnd() ) {
             const QString line = s.readLine();
             if ( rx.exactMatch( line ) ) {
