@@ -88,17 +88,12 @@ namespace KIO {
   class Job;
 }
 
-namespace MessageComposer {
-  class Composer;
-}
-
-namespace KPIM {
-  class SpellCheckLineEdit;
-}
-
 namespace MessageComposer {
   class ComposerLineEdit;
+  class Composer;
+  class SubjectLineEditWithAutoCorrection;
 }
+
 namespace MailCommon {
   class FolderRequester;
 }
@@ -220,7 +215,7 @@ class KMComposeWin : public KMail::Composer
     /**
      * Sets the focus to the edit-widget.
      */
-     void setReplyFocus( bool hasMessage = true );
+     void setFocusToEditor();
 
     /**
      * Sets the focus to the subject line edit. For use when creating a
@@ -235,6 +230,10 @@ class KMComposeWin : public KMail::Composer
 
      void addExtraCustomHeaders( const QMap<QByteArray, QString> &header);
 
+     KAction *lowerCaseAction() const { return mLowerCase; }
+     KAction *upperCaseAction() const { return mUpperCase; }
+
+
   private:
   /**
    * Write settings to app's config file.
@@ -601,7 +600,7 @@ class KMComposeWin : public KMail::Composer
     QWidget   *mMainWidget;
     Sonnet::DictionaryComboBox *mDictionaryCombo;
     MessageComposer::ComposerLineEdit *mEdtFrom, *mEdtReplyTo;
-    KPIM::SpellCheckLineEdit *mEdtSubject;
+    MessageComposer::SubjectLineEditWithAutoCorrection *mEdtSubject;
     QLabel    *mLblIdentity, *mLblTransport, *mLblFcc;
     QLabel    *mLblFrom, *mLblReplyTo;
     QLabel    *mLblSubject;
@@ -624,7 +623,6 @@ class KMComposeWin : public KMail::Composer
     uint mId;
     TemplateContext mContext;
 
-    KAction *mCleanSpace;
     KRecentFilesAction *mRecentAction;
 
     KToggleAction *mSignAction, *mEncryptAction, *mRequestMDNAction;
@@ -641,6 +639,9 @@ class KMComposeWin : public KMail::Composer
     KSelectAction *mCryptoModuleAction;
 
     KAction *mFindText, *mFindNextText, *mReplaceText, *mSelectAll;
+    KAction *mLowerCase;
+    KAction *mUpperCase;
+
   
     QSplitter *mHeadersToEditorSplitter;
     QWidget* mHeadersArea;
