@@ -58,6 +58,8 @@ using KMail::MailServiceImpl;
 #include "templateparser/templatesutil.h"
 
 #include "foldercollection.h"
+#include "editor/codecmanager.h"
+
 
 #include <kmessagebox.h>
 #include <knotification.h>
@@ -1388,6 +1390,7 @@ void KMKernel::slotShowConfigurationDialog()
 void KMKernel::slotConfigChanged()
 {
   readConfig();
+  CodecManager::self()->updatePreferredCharsets();
   emit configChanged();
 }
 
