@@ -14,7 +14,7 @@
 #include <kurl.h>
 
 #include "kmail_export.h"
-#include "globalsettings.h"
+#include "settings/globalsettings.h"
 #include <kcomponentdata.h>
 #include <akonadi/servermanager.h>
 #include "messageviewer/viewer/viewer.h"
@@ -56,10 +56,8 @@ namespace KMail {
   class UndoStack;
   class KMSystemTray;
 }
-namespace KPIM { class ProgressDialog; }
 using KMail::MailServiceImpl;
 using KMail::UndoStack;
-using KPIM::ProgressDialog;
 namespace MessageComposer {
 class AkonadiSender;
 }
@@ -470,9 +468,6 @@ signals:
   void startCheckMail();
   void endCheckMail();
 
-
-
-
 private slots:
   /** Updates identities when a transport has been deleted. */
   void transportRemoved( int id, const QString &name );
@@ -494,7 +489,6 @@ private slots:
   
 private:
   void resourceGoOnLine();
-  void migrateFromKMail1();
   void openReader( bool onlyCheck );
   QSharedPointer<MailCommon::FolderCollection> currentFolderCollection();
 
