@@ -21,7 +21,7 @@
 
 #include "kmsystemtray.h"
 #include "kmmainwidget.h"
-#include "globalsettings.h"
+#include "settings/globalsettings.h"
 #include "util/mailutil.h"
 #include "mailcommon/kernel/mailkernel.h"
 #include "mailcommon/folder/foldertreeview.h"
@@ -69,8 +69,8 @@ KMSystemTray::KMSystemTray(QObject *parent)
 {
     kDebug() << "Initting systray";
     setToolTipTitle( i18n("KMail") );
-    setToolTipIconByName( "kmail" );
-    setIconByName( "kmail" );
+    setToolTipIconByName( QLatin1String("kmail") );
+    setIconByName( QLatin1String("kmail") );
     mIcon = KIcon( QLatin1String("mail-unread-new") );
 
     KMMainWidget * mainWidget = kmkernel->getKMMainWidget();
@@ -114,9 +114,9 @@ bool KMSystemTray::buildPopupMenu()
 
     contextMenu()->addTitle(qApp->windowIcon(), i18n("KMail"));
     QAction * action;
-    if ( ( action = mainWidget->action("check_mail") ) )
+    if ( ( action = mainWidget->action(QLatin1String("check_mail")) ) )
         contextMenu()->addAction( action );
-    if ( ( action = mainWidget->action("check_mail_in") ) )
+    if ( ( action = mainWidget->action(QLatin1String("check_mail_in")) ) )
         contextMenu()->addAction( action );
 
     mSendQueued = mainWidget->sendQueuedAction();
@@ -124,16 +124,16 @@ bool KMSystemTray::buildPopupMenu()
     contextMenu()->addAction( mainWidget->sendQueueViaMenu() );
 
     contextMenu()->addSeparator();
-    if ( ( action = mainWidget->action("new_message") ) )
+    if ( ( action = mainWidget->action(QLatin1String("new_message")) ) )
         contextMenu()->addAction( action );
-    if ( ( action = mainWidget->action("kmail_configure_kmail") ) )
+    if ( ( action = mainWidget->action(QLatin1String("kmail_configure_kmail")) ) )
         contextMenu()->addAction( action );
     contextMenu()->addSeparator();
-    if ( (action = mainWidget->action("akonadi_work_offline") ) )
+    if ( (action = mainWidget->action(QLatin1String("akonadi_work_offline")) ) )
         contextMenu()->addAction( action );
     contextMenu()->addSeparator();
 
-    if ( ( action = actionCollection()->action("file_quit") ) )
+    if ( ( action = actionCollection()->action(QLatin1String("file_quit")) ) )
         contextMenu()->addAction( action );
 
     return true;
@@ -184,7 +184,7 @@ int KMSystemTray::mode() const
 void KMSystemTray::updateCount()
 {
     if (mCount == 0 || !mIconNotificationsEnabled) {
-        setIconByName( "kmail" );
+        setIconByName( QLatin1String("kmail") );
         return;
     }
     if (mShowUnreadMailCount) {
@@ -226,7 +226,7 @@ void KMSystemTray::updateCount()
 
         setIconByPixmap( iconPixmap );
     } else {
-        setIconByName( "mail-unread-new" );
+        setIconByPixmap( mIcon );
     }
 }
 
@@ -298,7 +298,7 @@ void KMSystemTray::slotContextMenuAboutToShow()
     }
 }
 
-void KMSystemTray::fillFoldersMenu( QMenu *menu, const QAbstractItemModel *model, const QString& parentName, const QModelIndex& parentIndex )
+void KMSystemTray::fillFoldersMenu( QMenu *menu, const QAbstractItemModel *model, const QString &parentName, const QModelIndex &parentIndex )
 {
     const int rowCount = model->rowCount( parentIndex );
     for ( int row = 0; row < rowCount; ++row ) {
@@ -330,8 +330,6 @@ void KMSystemTray::fillFoldersMenu( QMenu *menu, const QAbstractItemModel *model
     }
 }
 
-
-
 void KMSystemTray::hideKMail()
 {
     KMMainWidget * mainWidget = kmkernel->getKMMainWidget();
@@ -404,7 +402,7 @@ bool KMSystemTray::hasUnreadMail() const
     return ( mCount != 0 );
 }
 
-void KMSystemTray::slotSelectCollection(QAction*act)
+void KMSystemTray::slotSelectCollection(QAction *act)
 {
     const Akonadi::Collection::Id id = act->data().value<Akonadi::Collection::Id>();
     kmkernel->selectCollectionFromId( id );
@@ -421,7 +419,7 @@ void KMSystemTray::updateSystemTray()
     initListOfCollection();
 }
 
-void KMSystemTray::slotCollectionStatisticsChanged( Akonadi::Collection::Id id,const Akonadi::CollectionStatistics& )
+void KMSystemTray::slotCollectionStatisticsChanged( Akonadi::Collection::Id id, const Akonadi::CollectionStatistics & )
 {
     //Exclude sent mail folder
 
