@@ -161,7 +161,7 @@ void AddContactJob::start()
   // first check whether a contact with the same email exists already
   Akonadi::ContactSearchJob *searchJob = new Akonadi::ContactSearchJob( this );
   searchJob->setLimit( 1 );
-  searchJob->setQuery( Akonadi::ContactSearchJob::Email, d->mContact.preferredEmail(),
+  searchJob->setQuery( Akonadi::ContactSearchJob::Email, d->mContact.preferredEmail().toLower(),
                        Akonadi::ContactSearchJob::ExactMatch );
 
   connect( searchJob, SIGNAL(result(KJob*)), SLOT(slotSearchDone(KJob*)) );
