@@ -24,6 +24,8 @@
 #include <KLineEdit>
 
 #include <QLabel>
+#include <QDomNode>
+#include <QDebug>
 #include <QHBoxLayout>
 
 using namespace KSieveUi;
@@ -40,34 +42,76 @@ SieveAction* SieveActionReplace::newAction()
 QWidget *SieveActionReplace::createParamWidget( QWidget *parent ) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
-    w->setLayout(lay);
+    QGridLayout *grid = new QGridLayout;
+    grid->setMargin(0);
+    w->setLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Subject:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,0,0);
 
     KLineEdit *subject = new KLineEdit;
     subject->setObjectName(QLatin1String("subject"));
-    lay->addWidget(subject);
+    grid->addWidget(subject,0,1);
 
     lab = new QLabel(i18n("from:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,1,0);
 
     KLineEdit *headers = new KLineEdit;
     headers->setObjectName(QLatin1String("from"));
-    lay->addWidget(headers);
+    grid->addWidget(headers,1,1);
 
     lab = new QLabel(i18n("text:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,2,0);
 
     MultiLineEdit *text = new MultiLineEdit;
     text->setObjectName(QLatin1String("text"));
-    lay->addWidget(text);
+    grid->addWidget(text,2,1);
 
     return w;
 }
 
+bool SieveActionReplace::setParamWidgetValue(const QDomElement &element, QWidget *w , QString &error)
+{
+    QDomNode node = element.firstChild();
+    while (!node.isNull()) {
+        QDomElement e = node.toElement();
+        if (!e.isNull()) {
+            const QString tagName = e.tagName();
+            if (tagName == QLatin1String("str")) {
+                MultiLineEdit *edit = w->findChild<MultiLineEdit*>( QLatin1String("text") );
+                edit->setText(e.text());
+            } else if (tagName == QLatin1String("tag")) {
+                const QString tagValue = e.text();
+                if (tagValue == QLatin1String("subject")) {
+                    const QString strValue = AutoCreateScriptUtil::strValue(node);
+                    if (!strValue.isEmpty()) {
+                        KLineEdit *subject = w->findChild<KLineEdit*>(QLatin1String("subject"));
+                        subject->setText(strValue);
+                    }
+                } else if (tagValue == QLatin1String("from")) {
+                    const QString strValue = AutoCreateScriptUtil::strValue(node);
+                    if (!strValue.isEmpty()) {
+                        KLineEdit *headers = w->findChild<KLineEdit*>(QLatin1String("from"));
+                        headers->setText(strValue);
+                    }
+                } else {
+                    unknowTagValue(tagValue, error);
+                    qDebug()<<" SieveActionReplace::setParamWidgetValue unknown tagValue "<<tagValue;
+                }
+            } else if (tagName == QLatin1String("crlf")) {
+                //nothing
+            } else if (tagName == QLatin1String("comment")) {
+                //implement in the future ?
+            } else {
+                unknownTag(tagName, error);
+                qDebug()<<" SieveActionReplace::setParamWidgetValue unknown tagName "<<tagName;
+            }
+        }
+        node = node.nextSibling();
+    }
+    return true;
+}
+
 QString SieveActionReplace::code(QWidget *w) const
 {
     QString result = QLatin1String("replace ");
@@ -83,7 +127,6 @@ QString SieveActionReplace::code(QWidget *w) const
         result += QString::fromLatin1(":from \"%1\" ").arg(headersStr);
     }
 
-
     const MultiLineEdit *edit = w->findChild<MultiLineEdit*>( QLatin1String("text") );
     const QString text = edit->toPlainText();
     if (!text.isEmpty()) {
