@@ -16,6 +16,7 @@
 */
 
 #include "selectaddheaderpositioncombobox.h"
+#include "autocreatescripts/autocreatescriptutil_p.h"
 
 #include <KComboBox>
 #include <KLocale>
@@ -42,4 +43,15 @@ QString SelectAddHeaderPositionCombobox::code() const
     return itemData(currentIndex()).toString();
 }
 
+void SelectAddHeaderPositionCombobox::setCode(const QString &code, const QString &name, QString &error)
+{
+    const int index = findData(code);
+    if (index != -1) {
+        setCurrentIndex(index);
+    } else {
+        AutoCreateScriptUtil::comboboxItemNotFound(code, name, error);
+        setCurrentIndex(0);
+    }
+}
+
 #include "selectaddheaderpositioncombobox.moc"
