@@ -17,6 +17,8 @@
 
 #include "sievecondition.h"
 
+#include <KLocale>
+
 #include <QWidget>
 
 using namespace KSieveUi;
@@ -75,4 +77,29 @@ QString SieveCondition::help() const
     return QString();
 }
 
+bool SieveCondition::setParamWidgetValue(const QDomElement &/*element*/, QWidget */*parent*/, bool /*notCondition*/, QString &/*error*/)
+{
+    return true;
+}
+
+void SieveCondition::unknownTag(const QString &tag, QString &error)
+{
+    error += i18n("Unknown tag \"%1\" during parsing condition \"%2\"", tag, name()) + QLatin1Char('\n');
+}
+
+void SieveCondition::unknowTagValue(const QString &tagValue, QString &error)
+{
+    error += i18n("An unknown tag value \"%1\" was found during parsing condition \"%2\".", tagValue, name()) + QLatin1Char('\n');
+}
+
+void SieveCondition::tooManyArgument(const QString &tagName, int index, int maxValue, QString &error)
+{
+    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, tagName) + QLatin1Char('\n');
+}
+
+void SieveCondition::serverDoesNotSupportFeatures(const QString &feature, QString &error)
+{
+    error += i18n("A feature \"%1\" in condition \"%2\" is not supported by server", feature, name()) + QLatin1Char('\n');
+}
+
 #include "sievecondition.moc"
