@@ -40,6 +40,11 @@ public:
     QStringList needRequires(QWidget *parent) const;
 
     QString help() const;
+
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error );
+
+private:
+    bool mHasSpamTestPlusSupport;
 };
 }
 
