@@ -187,13 +187,16 @@ void SelectHeaderTypeComboBox::headerMap(bool onlyEnvelopType)
 {
     mHeaderMap.insert(QLatin1String("from"), i18n("From"));
     mHeaderMap.insert(QLatin1String("to"), i18n("To"));
+    mHeaderMap.insert(QLatin1String("Reply-To"), i18n("Reply To"));
+    mHeaderMap.insert(QLatin1String("cc"), i18n("Cc"));
+    mHeaderMap.insert(QLatin1String("bcc"), i18n("Bcc"));
     if (!onlyEnvelopType) {
-        mHeaderMap.insert(QLatin1String("cc"), i18n("Cc"));
-        mHeaderMap.insert(QLatin1String("bcc"), i18n("Bcc"));
+        mHeaderMap.insert(QLatin1String("Subject"), i18n("Subject"));
         mHeaderMap.insert(QLatin1String("sender"), i18n("Sender"));
+        mHeaderMap.insert(QLatin1String("Date"), i18n("Date"));
+        mHeaderMap.insert(QLatin1String("Message-ID"), i18n("Message Id"));
+        mHeaderMap.insert(QLatin1String("Content-Type"), i18n("Content type"));
     }
-    //mHeaderMap.insert(QLatin1String("sender-from"), i18n("Sender-From"));
-    //mHeaderMap.insert(QLatin1String("sender-to"), i18n("Sender-To"));
 }
 
 void SelectHeaderTypeComboBox::initialize(bool onlyEnvelopType)
@@ -209,7 +212,7 @@ void SelectHeaderTypeComboBox::initialize(bool onlyEnvelopType)
 
 QString SelectHeaderTypeComboBox::code() const
 {
-    QString str = itemData(currentIndex()).toString();
+    QString str = mCode.isEmpty() ? itemData(currentIndex()).toString() : mCode;
     if (str.isEmpty()) {
         str = currentText();
         if (str == i18n(selectMultipleHeaders)) {
@@ -222,4 +225,10 @@ QString SelectHeaderTypeComboBox::code() const
     return str;
 }
 
+void SelectHeaderTypeComboBox::setCode(const QString &code)
+{
+    lineEdit()->setText(code);
+    mCode = code;
+}
+
 #include "selectheadertypecombobox.moc"
