@@ -17,6 +17,7 @@
 
 #include "sieveincludewidget.h"
 #include "sievescriptblockwidget.h"
+#include "autocreatescripts/autocreatescriptutil_p.h"
 
 #include <KPushButton>
 #include <KLocale>
@@ -27,11 +28,12 @@
 #include <QLabel>
 #include <QToolButton>
 #include <QWhatsThis>
-
+#include <QDomNode>
+#include <QDebug>
 
 namespace KSieveUi {
 static int MINIMUMINCLUDEACTION = 1;
-static int MAXIMUMINCLUDEACTION = 8;
+static int MAXIMUMINCLUDEACTION = 20;
 
 SieveIncludeLocation::SieveIncludeLocation(QWidget *parent)
     : KComboBox(parent)
@@ -54,6 +56,17 @@ QString SieveIncludeLocation::code() const
     return itemData(currentIndex()).toString();
 }
 
+void SieveIncludeLocation::setCode(const QString &code, QString &error)
+{
+    const int index = findData(code);
+    if (index != -1) {
+        setCurrentIndex(index);
+    } else {
+        error += i18n("Unknown location type \"%1\" during parsing includes", code);
+        setCurrentIndex(0);
+    }
+}
+
 SieveIncludeActionWidget::SieveIncludeActionWidget(QWidget *parent)
     : QWidget(parent)
 {
@@ -62,7 +75,35 @@ SieveIncludeActionWidget::SieveIncludeActionWidget(QWidget *parent)
 
 SieveIncludeActionWidget::~SieveIncludeActionWidget()
 {
+}
 
+void SieveIncludeActionWidget::loadScript(const QDomElement &element, QString &error)
+{
+    QDomNode node = element.firstChild();
+    while (!node.isNull()) {
+        QDomElement e = node.toElement();
+        if (!e.isNull()) {
+            const QString tagName = e.tagName();
+            if (tagName == QLatin1String("tag")) {
+                const QString tagValue = e.text();
+                if (tagValue == QLatin1String("personal") ||
+                        tagValue == QLatin1String("global")) {
+                    mLocation->setCode(AutoCreateScriptUtil::tagValue(tagValue), error);
+                } else if (tagValue == QLatin1String("optional")) {
+                    mOptional->setChecked(true);
+                } else if (tagValue == QLatin1String("once")) {
+                    mOnce->setChecked(true);
+                } else {
+                    qDebug()<<" SieveIncludeActionWidget::loadScript unknown tagValue "<<tagValue;
+                }
+            } else if (tagName == QLatin1String("str")) {
+                mIncludeName->setText(e.text());
+            } else {
+                qDebug()<<" SieveIncludeActionWidget::loadScript unknown tagName "<<tagName;
+            }
+        }
+        node = node.nextSibling();
+    }
 }
 
 void SieveIncludeActionWidget::generatedScript(QString &script)
@@ -129,6 +170,11 @@ void SieveIncludeActionWidget::slotRemoveWidget()
     emit removeWidget( this );
 }
 
+bool SieveIncludeActionWidget::isInitialized() const
+{
+    return !mIncludeName->text().isEmpty();
+}
+
 void SieveIncludeActionWidget::updateAddRemoveButton( bool addButtonEnabled, bool removeButtonEnabled )
 {
     mAdd->setEnabled(addButtonEnabled);
@@ -172,6 +218,11 @@ void SieveIncludeWidget::generatedScript(QString &script, QStringList &requires)
     }
 }
 
+void SieveIncludeWidget::loadScript(const QDomElement &element, QString &error)
+{
+    mIncludeLister->loadScript(element, error);
+}
+
 SieveIncludeWidgetLister::SieveIncludeWidgetLister(QWidget *parent)
     : KPIM::KWidgetLister(false, MINIMUMINCLUDEACTION, MAXIMUMINCLUDEACTION, parent)
 {
@@ -196,7 +247,6 @@ void SieveIncludeWidgetLister::slotRemoveWidget( QWidget *w )
     updateAddRemoveButton();
 }
 
-
 void SieveIncludeWidgetLister::updateAddRemoveButton()
 {
     QList<QWidget*> widgetList = widgets();
@@ -253,6 +303,20 @@ QWidget *SieveIncludeWidgetLister::createWidget( QWidget *parent )
     return w;
 }
 
+void SieveIncludeWidgetLister::loadScript(const QDomElement &element, QString &error)
+{
+    if (widgets().count() == MAXIMUMINCLUDEACTION) {
+        error += QLatin1Char('\n') + i18n("We can not add more includes elements.") + QLatin1Char('\n');
+        return;
+    }
+    SieveIncludeActionWidget *w = static_cast<SieveIncludeActionWidget *>(widgets().last());
+    if (w->isInitialized()) {
+        addWidgetAfterThisWidget(widgets().last());
+        w = static_cast<SieveIncludeActionWidget *>(widgets().last());
+    }
+    w->loadScript(element, error);
+}
+
 }
 
 #include "sieveincludewidget.moc"
