@@ -16,8 +16,8 @@
 */
 
 #include "sievescriptdescriptiondialog.h"
+#include "pimcommon/texteditor/richtexteditor/richtexteditorwidget.h"
 
-#include <KTextEdit>
 #include <KLocale>
 
 #include <QHBoxLayout>
@@ -29,7 +29,7 @@ SieveScriptDescriptionDialog::SieveScriptDescriptionDialog(QWidget *parent)
 {
     setCaption( i18n( "Description" ) );
     setButtons( Ok|Cancel );
-    mEdit = new KTextEdit;
+    mEdit = new PimCommon::RichTextEditorWidget;
     mEdit->setAcceptRichText(false);
     setMainWidget(mEdit);
     readConfig();
@@ -54,11 +54,9 @@ QString SieveScriptDescriptionDialog::description() const
 void SieveScriptDescriptionDialog::readConfig()
 {
     KConfigGroup group( KGlobal::config(), "SieveScriptDescriptionDialog" );
-    const QSize sizeDialog = group.readEntry( "Size", QSize() );
+    const QSize sizeDialog = group.readEntry( "Size", QSize(800,600) );
     if ( sizeDialog.isValid() ) {
         resize( sizeDialog );
-    } else {
-        resize( 800,600);
     }
 }
 
