@@ -218,6 +218,8 @@ void ManageSieveScriptsDialog::slotRefresh()
     }
     slotUpdateButtons();
     mListView->setNoImapFound(noImapFound);
+    if (!noImapFound)
+       mBlockSignal = false;
 }
 
 void ManageSieveScriptsDialog::slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &listScript, const QString &activeScript)
@@ -237,6 +239,7 @@ void ManageSieveScriptsDialog::slotGotList(KManageSieve::SieveJob *job, bool suc
                 new QTreeWidgetItem( parent );
         item->setText( 0, i18n( "Failed to fetch the list of scripts" ) );
         item->setFlags( item->flags() & ~Qt::ItemIsEnabled );
+        mListView->expandItem( parent );
         return;
     }
 
