@@ -591,7 +591,7 @@ void Vacation::slotGetResult( KManageSieve::SieveJob * job, bool success,
              << script;
     mSieveJob = 0; // job deletes itself after returning from this slot!
 
-    if ( !mCheckOnly && mUrl.protocol() == QLatin1String("sieve") && !job->sieveCapabilities().isEmpty() &&
+    if ( !mCheckOnly && mUrl.protocol() == QLatin1String("sieve") &&
          !job->sieveCapabilities().contains(QLatin1String("vacation")) ) {
         KMessageBox::sorry( 0, i18n( "Your server did not list \"vacation\" in "
                                      "its list of supported Sieve extensions;\n"
