@@ -49,13 +49,13 @@
 class QStringList;
 
 namespace KABC {
-class Addressee;
+  class Addressee;
 }
 
 namespace Kleo {
 
 
-/**
+  /**
      \short A class to resolve signing/encryption keys w.r.t. per-recipient preferences
 
      \section Step 1: Set the information needed
@@ -128,8 +128,8 @@ namespace Kleo {
      a copy of it's own to hide the other secondary recipients.
     */
 
-class MESSAGECOMPOSER_EXPORT KeyResolver {
-public:
+  class MESSAGECOMPOSER_EXPORT KeyResolver {
+  public:
     KeyResolver( bool encToSelf, bool showApproval, bool oppEncryption,
                  unsigned int format,
                  int encrKeyNearExpiryThresholdDays,
@@ -141,35 +141,26 @@ public:
 
     ~KeyResolver();
 
-    struct ContactPreferences {
-        ContactPreferences();
-        Kleo::EncryptionPreference encryptionPreference;
-        Kleo::SigningPreference signingPreference;
-        Kleo::CryptoMessageFormat cryptoMessageFormat;
-        QStringList pgpKeyFingerprints;
-        QStringList smimeCertFingerprints;
-    };
-
     struct Item : public KeyApprovalDialog::Item {
-        Item()
-            : KeyApprovalDialog::Item(),
-              signPref( UnknownSigningPreference ),
-              format( AutoFormat ),
-              needKeys( true ) {}
-        Item( const QString & a,
-              EncryptionPreference e, SigningPreference s,
-              CryptoMessageFormat f )
-            : KeyApprovalDialog::Item( a, std::vector<GpgME::Key>(), e ),
-              signPref( s ), format( f ), needKeys( true ) {}
-        Item( const QString & a, const std::vector<GpgME::Key> & k,
-              EncryptionPreference e, SigningPreference s,
-              CryptoMessageFormat f )
-            : KeyApprovalDialog::Item( a, k, e ),
-              signPref( s ), format( f ), needKeys( false ) {}
+      Item()
+        : KeyApprovalDialog::Item(),
+          signPref( UnknownSigningPreference ),
+          format( AutoFormat ),
+          needKeys( true ) {}
+      Item( const QString & a,
+            EncryptionPreference e, SigningPreference s,
+            CryptoMessageFormat f )
+        : KeyApprovalDialog::Item( a, std::vector<GpgME::Key>(), e ),
+          signPref( s ), format( f ), needKeys( true ) {}
+      Item( const QString & a, const std::vector<GpgME::Key> & k,
+            EncryptionPreference e, SigningPreference s,
+            CryptoMessageFormat f )
+        : KeyApprovalDialog::Item( a, k, e ),
+          signPref( s ), format( f ), needKeys( false ) {}
 
-        SigningPreference signPref;
-        CryptoMessageFormat format;
-        bool needKeys;
+      SigningPreference signPref;
+      CryptoMessageFormat format;
+      bool needKeys;
     };
 
 
@@ -222,12 +213,12 @@ public:
     std::vector<GpgME::Key> signingKeys( CryptoMessageFormat f ) const;
 
     struct SplitInfo {
-        SplitInfo() {}
-        SplitInfo( const QStringList & r ) : recipients( r ) {}
-        SplitInfo( const QStringList & r, const std::vector<GpgME::Key> & k )
-            : recipients( r ), keys( k ) {}
-        QStringList recipients;
-        std::vector<GpgME::Key> keys;
+      SplitInfo() {}
+      SplitInfo( const QStringList & r ) : recipients( r ) {}
+      SplitInfo( const QStringList & r, const std::vector<GpgME::Key> & k )
+        : recipients( r ), keys( k ) {}
+      QStringList recipients;
+      std::vector<GpgME::Key> keys;
     };
     /** @return the found distinct sets of items for format \a f.  The
         returned vector will contain more than one item only if
@@ -235,16 +226,16 @@ public:
     */
     std::vector<SplitInfo> encryptionItems( CryptoMessageFormat f ) const;
 
-private:
+  private:
     void dump() const;
     std::vector<Item> getEncryptionItems( const QStringList & recipients );
     std::vector<GpgME::Key> getEncryptionKeys( const QString & recipient, bool quiet ) const;
 
-    Kpgp::Result showKeyApprovalDialog(bool &finalySendUnencrypted);
+    Kpgp::Result showKeyApprovalDialog();
 
     bool encryptionPossible() const;
     bool signingPossible() const;
-    Kpgp::Result resolveEncryptionKeys(bool signingRequested , bool &finalySendUnencrypted);
+    Kpgp::Result resolveEncryptionKeys( bool signingRequested );
     Kpgp::Result resolveSigningKeysForEncryption();
     Kpgp::Result resolveSigningKeysForSigningOnly();
     Kpgp::Result checkKeyNearExpiry( const GpgME::Key & key,
@@ -269,23 +260,44 @@ private:
     QStringList keysForAddress( const QString & address ) const;
     void setKeysForAddress( const QString & address, const QStringList& pgpKeyFingerprints, const QStringList& smimeCertFingerprints ) const;
 
-    bool encryptToSelf() const;
-    bool showApprovalDialog() const;
+    bool encryptToSelf() const { return mEncryptToSelf; }
+    bool showApprovalDialog() const { return mShowApprovalDialog; }
 
-    int encryptKeyNearExpiryWarningThresholdInDays() const;
-    int signingKeyNearExpiryWarningThresholdInDays() const;
+    int encryptKeyNearExpiryWarningThresholdInDays() const {
+      return mEncryptKeyNearExpiryWarningThreshold;
+    }
+    int signingKeyNearExpiryWarningThresholdInDays() const {
+      return mSigningKeyNearExpiryWarningThreshold;
+    }
 
-    int encryptRootCertNearExpiryWarningThresholdInDays() const;
-    int signingRootCertNearExpiryWarningThresholdInDays() const;
+    int encryptRootCertNearExpiryWarningThresholdInDays() const {
+      return mEncryptRootCertNearExpiryWarningThreshold;
+    }
+    int signingRootCertNearExpiryWarningThresholdInDays() const {
+      return mSigningRootCertNearExpiryWarningThreshold;
+    }
 
-    int encryptChainCertNearExpiryWarningThresholdInDays() const;
-    int signingChainCertNearExpiryWarningThresholdInDays() const;
+    int encryptChainCertNearExpiryWarningThresholdInDays() const {
+      return mEncryptChainCertNearExpiryWarningThreshold;
+    }
+    int signingChainCertNearExpiryWarningThresholdInDays() const {
+      return mSigningChainCertNearExpiryWarningThreshold;
+    }
 
+    struct ContactPreferences {
+      ContactPreferences();
+      Kleo::EncryptionPreference encryptionPreference;
+      Kleo::SigningPreference signingPreference;
+      Kleo::CryptoMessageFormat cryptoMessageFormat;
+      QStringList pgpKeyFingerprints;
+      QStringList smimeCertFingerprints;
+    };
 
     ContactPreferences lookupContactPreferences( const QString& address ) const;
+    void writeCustomContactProperties( KABC::Addressee &contact, const ContactPreferences& pref ) const;
     void saveContactPreference( const QString& email, const ContactPreferences& pref ) const;
 
-private:
+  private:
     class EncryptionPreferenceCounter;
     friend class ::Kleo::KeyResolver::EncryptionPreferenceCounter;
     class SigningPreferenceCounter;
@@ -305,7 +317,7 @@ private:
     const int mSigningRootCertNearExpiryWarningThreshold;
     const int mEncryptChainCertNearExpiryWarningThreshold;
     const int mSigningChainCertNearExpiryWarningThreshold;
-};
+  };
 
 } // namespace Kleo
 
