@@ -513,6 +513,13 @@ KMime::Message::Ptr MessageFactory::createRedirect( const QString &toStr, int tr
     .arg( ident.fullName() )
     .arg( ident.primaryEmailAddress() );
 
+    // Clean up any resent headers
+    msg->removeHeader( "Resent-Cc" );
+    msg->removeHeader( "Resent-Bcc" );
+    msg->removeHeader( "Resent-Sender" );
+    // date, from to and id will be set anyway
+
+
   // format the current date to be used in Resent-Date:
   QString newDate = KDateTime::currentLocalDateTime().toString( KDateTime::RFCDateDay );
 
@@ -533,26 +540,16 @@ KMime::Message::Ptr MessageFactory::createRedirect( const QString &toStr, int tr
   header = new KMime::Headers::Generic( "Resent-From", msg.get(), strFrom, "utf-8" );
   msg->setHeader( header );
 
-  KMime::Headers::To* headerT = new KMime::Headers::To( msg.get(), toStr, "utf-8" );
-  msg->setHeader( headerT );
+  if ( msg->to(false) ) {
+    KMime::Headers::To* headerT = new KMime::Headers::To( msg.get(), m_origMsg->to()->asUnicodeString(), "utf-8" );
+    msg->setHeader( headerT );
+  }
 
   header = new KMime::Headers::Generic( "Resent-To", msg.get(), toStr, "utf-8" );
   msg->setHeader( header );
 
-  if( msg->cc( false ) ) {
-    header = new KMime::Headers::Generic( "Resent-Cc", msg.get(), m_origMsg->cc()->asUnicodeString(), "utf-8" );
-    msg->setHeader( header );
-  }
-
-  if( msg->bcc( false ) ) {
-    header = new KMime::Headers::Generic( "Resent-Bcc", msg.get(), m_origMsg->bcc()->asUnicodeString(), "utf-8" );
-    msg->setHeader( header );
-  }
-
   header = new KMime::Headers::Generic( "X-KMail-Redirect-From", msg.get(), strByWayOf, "utf-8" );
   msg->setHeader( header );
-  header = new KMime::Headers::Generic( "X-KMail-Recipients", msg.get(), toStr, "utf-8" );
-  msg->setHeader( header );
 
 
   if ( transportId != -1 ) {
