@@ -20,6 +20,8 @@
 #include "widgets/minimumcombobox.h"
 #include "translatorutil.h"
 #include "googletranslator.h"
+#include "pimcommon/texteditor/plaintexteditor/plaintexteditorwidget.h"
+
 #include <KTextEdit>
 #include <KComboBox>
 #include <KPushButton>
@@ -28,6 +30,7 @@
 #include <KDebug>
 #include <KConfigGroup>
 #include <KSeparator>
+#include <KMessageBox>
 
 #include <kpimutils/progressindicatorwidget.h>
 
@@ -48,7 +51,9 @@ class TranslatorWidget::TranslatorWidgetPrivate
 {
 public:
     TranslatorWidgetPrivate()
-        : abstractTranslator(0)
+        : abstractTranslator(0),
+          languageSettingsChanged(false),
+          networkUp(true)
     {
 
     }
@@ -63,16 +68,20 @@ public:
     QMap<QString, QMap<QString, QString> > listLanguage;
     QByteArray data;
     TranslatorTextEdit *inputText;
-    TranslatorResultTextEdit *translatedText;
+    PimCommon::PlainTextEditorWidget *translatedText;
+    TranslatorResultTextEdit *translatorResultTextEdit;
     MinimumComboBox *from;
     MinimumComboBox *to;
     KPushButton *translate;
     PimCommon::AbstractTranslator *abstractTranslator;
     KPIMUtils::ProgressIndicatorWidget *progressIndictor;
+    KPushButton *invert;
     QSplitter *splitter;
+    bool languageSettingsChanged;
+    bool networkUp;
 };
 
-void TranslatorWidget::TranslatorWidgetPrivate::fillToCombobox( const QString& lang )
+void TranslatorWidget::TranslatorWidgetPrivate::fillToCombobox( const QString &lang )
 {
     to->clear();
     const QMap<QString, QString> list = listLanguage.value( lang );
@@ -94,7 +103,7 @@ void TranslatorWidget::TranslatorWidgetPrivate::initLanguage()
 
 
 TranslatorResultTextEdit::TranslatorResultTextEdit(QWidget *parent)
-    : KTextEdit(parent),
+    : PimCommon::PlainTextEditor(parent),
       mResultFailed(false)
 {
     setReadOnly( true );
@@ -121,7 +130,7 @@ void TranslatorResultTextEdit::paintEvent( QPaintEvent *event )
 
         p.drawText( QRect( 0, 0, width(), height() ), Qt::AlignCenter, i18n( "Problem when connecting to the translator web site." ) );
     } else {
-        KTextEdit::paintEvent( event );
+        PimCommon::PlainTextEditor::paintEvent( event );
     }
 }
 
@@ -140,13 +149,13 @@ void TranslatorTextEdit::dropEvent( QDropEvent *event )
             cursor.endEditBlock();
             event->setDropAction(Qt::CopyAction);
             event->accept();
+            Q_EMIT translateText();
             return;
         }
     }
     QTextEdit::dropEvent(event);
 }
 
-
 TranslatorWidget::TranslatorWidget( QWidget* parent )
     : QWidget( parent ),
       d( new TranslatorWidgetPrivate )
@@ -171,8 +180,10 @@ TranslatorWidget::~TranslatorWidget()
 void TranslatorWidget::writeConfig()
 {
     KConfigGroup myGroup( KGlobal::config(), "TranslatorWidget" );
-    myGroup.writeEntry( QLatin1String( "FromLanguage" ), d->from->itemData(d->from->currentIndex()).toString() );
-    myGroup.writeEntry( "ToLanguage", d->to->itemData(d->to->currentIndex()).toString() );
+    if (d->languageSettingsChanged) {
+        myGroup.writeEntry( QLatin1String( "FromLanguage" ), d->from->itemData(d->from->currentIndex()).toString() );
+        myGroup.writeEntry( "ToLanguage", d->to->itemData(d->to->currentIndex()).toString() );
+    }
     myGroup.writeEntry( "mainSplitter", d->splitter->sizes());
     myGroup.sync();
 }
@@ -199,15 +210,15 @@ void TranslatorWidget::readConfig()
 
 void TranslatorWidget::init()
 {
-    d->abstractTranslator = new /*BabelFishTranslator*/GoogleTranslator();
+    d->abstractTranslator = new GoogleTranslator();
     connect(d->abstractTranslator, SIGNAL(translateDone()), SLOT(slotTranslateDone()));
-    connect(d->abstractTranslator, SIGNAL(translateFailed(bool)), SLOT(slotTranslateFailed(bool)));
+    connect(d->abstractTranslator, SIGNAL(translateFailed(bool,QString)), SLOT(slotTranslateFailed(bool,QString)));
 
     QVBoxLayout *layout = new QVBoxLayout( this );
     layout->setMargin( 0 );
     QHBoxLayout *hboxLayout = new QHBoxLayout;
     QToolButton * closeBtn = new QToolButton( this );
-    closeBtn->setIcon( KIcon( "dialog-close" ) );
+    closeBtn->setIcon( KIcon( QLatin1String("dialog-close") ) );
     closeBtn->setIconSize( QSize( 16, 16 ) );
     closeBtn->setToolTip( i18n( "Close" ) );
 
@@ -227,16 +238,17 @@ void TranslatorWidget::init()
     hboxLayout->addWidget( label );
     d->to = new MinimumComboBox;
     connect( d->to, SIGNAL(currentIndexChanged(int)), SLOT(slotTranslate()) );
+    connect( d->to, SIGNAL(currentIndexChanged(int)), SLOT(slotConfigChanged()));
     hboxLayout->addWidget( d->to );
 
     KSeparator *separator = new KSeparator;
     separator->setOrientation(Qt::Vertical);
     hboxLayout->addWidget( separator );
 
-    KPushButton *invert = new KPushButton(
+    d->invert = new KPushButton(
                 i18nc("Invert language choices so that from becomes to and to becomes from", "Invert"),this);
-    connect(invert, SIGNAL(clicked()), this, SLOT(slotInvertLanguage()));
-    hboxLayout->addWidget(invert);
+    connect(d->invert, SIGNAL(clicked()), this, SLOT(slotInvertLanguage()));
+    hboxLayout->addWidget(d->invert);
 
     KPushButton *clear = new KPushButton(i18n("Clear"),this);
 #ifndef QT_NO_ACCESSIBILITY
@@ -255,9 +267,9 @@ void TranslatorWidget::init()
     connect( d->translate, SIGNAL(clicked()), SLOT(slotTranslate()) );
 
 #if !defined(NDEBUG)
-    KPushButton *debug = new KPushButton(i18n("Debug"));
-    connect(debug,SIGNAL(clicked()),this,SLOT(slotDebug()));
-    hboxLayout->addWidget( debug );
+    QPushButton *debugButton = new QPushButton( i18n("Debug") );
+    hboxLayout->addWidget( debugButton );
+    connect( debugButton, SIGNAL(clicked()), SLOT(slotDebug()));
 #endif
 
     d->progressIndictor = new KPIMUtils::ProgressIndicatorWidget(this);
@@ -270,12 +282,15 @@ void TranslatorWidget::init()
     d->splitter = new QSplitter;
     d->splitter->setChildrenCollapsible( false );
     d->inputText = new TranslatorTextEdit;
+    d->inputText->enableFindReplace(false);
     d->inputText->setAcceptRichText(false);
     d->inputText->setClickMessage(i18n("Drag text that you want to translate."));
     connect( d->inputText, SIGNAL(textChanged()), SLOT(slotTextChanged()) );
+    connect( d->inputText, SIGNAL(translateText()), SLOT(slotTranslate()));
 
     d->splitter->addWidget( d->inputText );
-    d->translatedText = new TranslatorResultTextEdit;
+    d->translatorResultTextEdit = new TranslatorResultTextEdit;
+    d->translatedText = new PimCommon::PlainTextEditorWidget(d->translatorResultTextEdit, this);
     d->translatedText->setReadOnly( true );
     d->splitter->addWidget( d->translatedText );
 
@@ -283,13 +298,30 @@ void TranslatorWidget::init()
 
     d->initLanguage();
     connect( d->from, SIGNAL(currentIndexChanged(int)), SLOT(slotFromLanguageChanged(int)) );
+    connect( d->from, SIGNAL(currentIndexChanged(int)), SLOT(slotConfigChanged()));
 
     d->from->setCurrentIndex( 0 ); //Fill "to" combobox
-    slotFromLanguageChanged( 0 );
+    slotFromLanguageChanged( 0, true );
     slotTextChanged();
     readConfig();
     hide();
     setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+    d->languageSettingsChanged = false;
+
+    connect ( Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
+              this, SLOT(slotSystemNetworkStatusChanged(Solid::Networking::Status)) );
+    Solid::Networking::Status networkStatus = Solid::Networking::status();
+    if ( ( networkStatus == Solid::Networking::Unconnected ) ||
+         ( networkStatus == Solid::Networking::Disconnecting ) ||
+         ( networkStatus == Solid::Networking::Connecting ))
+        d->networkUp = false;
+    else
+        d->networkUp = true;
+}
+
+void TranslatorWidget::slotConfigChanged()
+{
+    d->languageSettingsChanged = true;
 }
 
 void TranslatorWidget::slotTextChanged()
@@ -297,9 +329,10 @@ void TranslatorWidget::slotTextChanged()
     d->translate->setEnabled( !d->inputText->document()->isEmpty() );
 }
 
-void TranslatorWidget::slotFromLanguageChanged( int index )
+void TranslatorWidget::slotFromLanguageChanged(int index, bool initialize)
 {
     const QString lang = d->from->itemData(index).toString();
+    d->invert->setEnabled(lang != QLatin1String("auto"));
     const QString to = d->to->itemData(d->to->currentIndex()).toString();
     d->to->blockSignals(true);
     d->fillToCombobox( lang );
@@ -308,23 +341,28 @@ void TranslatorWidget::slotFromLanguageChanged( int index )
     if ( indexTo != -1 ) {
         d->to->setCurrentIndex( indexTo );
     }
-    slotTranslate();
+    if (!initialize)
+        slotTranslate();
 }
 
 void TranslatorWidget::setTextToTranslate( const QString& text)
 {
     d->inputText->setPlainText( text );
-    d->translatedText->clear();
+    d->translatorResultTextEdit->clear();
     slotTranslate();
 }
 
-
 void TranslatorWidget::slotTranslate()
 {
-    const QString textToTranslate = d->inputText->toPlainText();
-    if ( textToTranslate.isEmpty() )
+    if (!d->networkUp) {
+        KMessageBox::information(this, i18n("No network connection detected, we cannot translate text."), i18n("No network"));
         return;
-    d->translatedText->clear();
+    }
+    const QString textToTranslate = d->inputText->toPlainText();
+    if ( textToTranslate.trimmed().isEmpty() )
+        return;
+
+    d->translatorResultTextEdit->clear();
 
     const QString from = d->from->itemData(d->from->currentIndex()).toString();
     const QString to = d->to->itemData(d->to->currentIndex()).toString();
@@ -341,25 +379,29 @@ void TranslatorWidget::slotTranslateDone()
 {
     d->translate->setEnabled( true );
     d->progressIndictor->stop();
-    d->translatedText->setResultFailed(false);
-    d->translatedText->setPlainText(d->abstractTranslator->resultTranslate());
+    d->translatorResultTextEdit->setResultFailed(false);
+    d->translatorResultTextEdit->setPlainText(d->abstractTranslator->resultTranslate());
 }
 
-void TranslatorWidget::slotTranslateFailed(bool signalFailed)
+void TranslatorWidget::slotTranslateFailed(bool signalFailed, const QString &message)
 {
     d->translate->setEnabled( true );
     d->progressIndictor->stop();
-    d->translatedText->setResultFailed(signalFailed);
-    d->translatedText->clear();
+    d->translatorResultTextEdit->setResultFailed(signalFailed);
+    d->translatorResultTextEdit->clear();
+    if (!message.isEmpty()) {
+        KMessageBox::error(this, message, i18n("Translate error"));
+    }
 }
 
 void TranslatorWidget::slotInvertLanguage()
 {
-    const QString toLanguage = d->to->itemData(d->to->currentIndex()).toString();
     const QString fromLanguage = d->from->itemData(d->from->currentIndex()).toString();
+    // don't invert when fromLanguage == auto
+    if (fromLanguage == QLatin1String("auto"))
+        return;
 
-    d->from->blockSignals(true);
-    d->to->blockSignals(true);
+    const QString toLanguage = d->to->itemData(d->to->currentIndex()).toString();
     const int indexFrom = d->from->findData( toLanguage );
     if ( indexFrom != -1 ) {
         d->from->setCurrentIndex( indexFrom );
@@ -368,15 +410,13 @@ void TranslatorWidget::slotInvertLanguage()
     if ( indexTo != -1 ) {
         d->to->setCurrentIndex( indexTo );
     }
-    d->from->blockSignals(false);
-    d->to->blockSignals(false);
     slotTranslate();
 }
 
 void TranslatorWidget::slotCloseWidget()
 {
     d->inputText->clear();
-    d->translatedText->clear();
+    d->translatorResultTextEdit->clear();
     d->progressIndictor->stop();
     hide();
     Q_EMIT translatorWasClosed();
@@ -402,13 +442,24 @@ bool TranslatorWidget::event(QEvent* e)
 void TranslatorWidget::slotClear()
 {
     d->inputText->clear();
-    d->translatedText->clear();
+    d->translatorResultTextEdit->clear();
     d->translate->setEnabled( false );
 }
 
 void TranslatorWidget::slotDebug()
 {
+#if !defined(NDEBUG)
     d->abstractTranslator->debug();
+#endif
+}
+
+void TranslatorWidget::slotSystemNetworkStatusChanged( Solid::Networking::Status status )
+{
+    if ( status == Solid::Networking::Connected || status == Solid::Networking::Unknown) {
+        d->networkUp = true;
+    } else {
+        d->networkUp = false;
+    }
 }
 
 #include "translatorwidget.moc"
