@@ -21,6 +21,7 @@
 #include "customtemplates_kfg.h"
 #include "globalsettings_base.h"
 #include "ui_customtemplates_base.h"
+#include "pimcommon/texteditor/richtexteditor/richtexteditor.h"
 
 #include <KIconLoader>
 #include <KLocale>
@@ -38,10 +39,10 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*> &actionCollect
   mUi = new Ui_CustomTemplatesBase;
   mUi->setupUi( this );
 
-  mUi->mAdd->setIcon( KIcon( "list-add" ) );
+  mUi->mAdd->setIcon( KIcon( QLatin1String("list-add") ) );
   mUi->mAdd->setEnabled( false );
-  mUi->mRemove->setIcon( KIcon( "list-remove" ) );
-  mUi->mDuplicate->setIcon( KIcon( "edit-copy" ) );
+  mUi->mRemove->setIcon( KIcon( QLatin1String("list-remove") ) );
+  mUi->mDuplicate->setIcon( KIcon( QLatin1String("edit-copy") ) );
 
   mUi->mList->setColumnWidth( 0, 100 );
   mUi->mList->header()->setStretchLastSection( true );
@@ -50,7 +51,7 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*> &actionCollect
   mUi->mEditFrame->setEnabled( false );
 
   mUi->mName->setTrapReturnKey( true );
-  connect( mUi->mEdit, SIGNAL(textChanged()),
+  connect( mUi->mEdit->editor(), SIGNAL(textChanged()),
            this, SLOT(slotTextChanged()) );
   connect( mUi->mToEdit, SIGNAL(textChanged()),
            this, SLOT(slotTextChanged()) );
@@ -84,9 +85,9 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*> &actionCollect
 
   mUi->mKeySequenceWidget->setCheckActionCollections( actionCollection );
 
-  mReplyPix = KIconLoader().loadIcon( "mail-reply-sender", KIconLoader::Small );
-  mReplyAllPix = KIconLoader().loadIcon( "mail-reply-all", KIconLoader::Small );
-  mForwardPix = KIconLoader().loadIcon( "mail-forward", KIconLoader::Small );
+  mReplyPix = KIconLoader().loadIcon( QLatin1String("mail-reply-sender"), KIconLoader::Small );
+  mReplyAllPix = KIconLoader().loadIcon( QLatin1String("mail-reply-all"), KIconLoader::Small );
+  mForwardPix = KIconLoader().loadIcon( QLatin1String("mail-forward"), KIconLoader::Small );
 
   mUi->mType->clear();
   mUi->mType->addItem( QPixmap(), i18nc( "Message->", "Universal" ) );
@@ -219,7 +220,7 @@ void CustomTemplates::save()
 {
   // Before saving the new templates, delete the old ones. That needs to be done before
   // saving, since otherwise a new template with the new name wouldn't get saved.
-  KSharedConfig::Ptr config = KSharedConfig::openConfig( "customtemplatesrc", KConfig::NoGlobals );
+  KSharedConfig::Ptr config = KSharedConfig::openConfig( QLatin1String("customtemplatesrc"), KConfig::NoGlobals );
   foreach ( const QString &item, mItemsToDelete ) {
     CTemplates t( item );
     const QString configGroup = t.currentGroup();
@@ -236,7 +237,7 @@ void CustomTemplates::save()
     CTemplates t(name);
     QString content = it->content();
     if ( content.trimmed().isEmpty() ) {
-      content = "%BLANK";
+      content = QLatin1String("%BLANK");
     }
 
     t.setContent( content );
@@ -256,11 +257,11 @@ void CustomTemplates::save()
 
 void CustomTemplates::slotInsertCommand( const QString &cmd, int adjustCursor )
 {
-  QTextCursor cursor = mUi->mEdit->textCursor();
+  QTextCursor cursor = mUi->mEdit->editor()->textCursor();
   cursor.insertText( cmd );
   cursor.setPosition( cursor.position() + adjustCursor );
-  mUi->mEdit->setTextCursor( cursor );
-  mUi->mEdit->setFocus();
+  mUi->mEdit->editor()->setTextCursor( cursor );
+  mUi->mEdit->editor()->setFocus();
 }
 
 bool CustomTemplates::nameAlreadyExists( const QString &str, QTreeWidgetItem *item )
@@ -272,7 +273,7 @@ bool CustomTemplates::nameAlreadyExists( const QString &str, QTreeWidgetItem *it
       KMessageBox::error(
         this,
         i18n( "A template with same name already exists." ),
-        i18n( "Can not create template" ) );
+        i18n( "Cannot create template" ) );
       return true;
     }
     ++lit;
@@ -293,7 +294,7 @@ void CustomTemplates::slotAddClicked()
     // FIXME There must be a better way of doing this...
     QKeySequence nullShortcut;
     CustomTemplateItem *item =
-      new CustomTemplateItem( mUi->mList, str, "", nullShortcut, TUniversal,
+            new CustomTemplateItem( mUi->mList, str, QString(), nullShortcut, TUniversal,
                               QString(), QString() );
     item->setText( 0, indexToType( TUniversal ) );
     item->setText( 1, str );
@@ -325,7 +326,7 @@ QString CustomTemplates::createUniqueName( const QString &name ) const
         found = true;
         ++counter;
         uniqueName = name;
-        uniqueName += QString( " (" ) + QString::number( counter ) + QString( ")" );
+        uniqueName += QLatin1String( " (" ) + QString::number( counter ) + QLatin1String( ")" );
         break;
       }
       lit++;
@@ -398,7 +399,7 @@ void CustomTemplates::slotListSelectionChanged()
     mUi->mDuplicate->setEnabled(true);
     CustomTemplateItem *vitem = static_cast<CustomTemplateItem*>( item );
     mBlockChangeSignal = true;
-    mUi->mEdit->setText( vitem->content() );
+    mUi->mEdit->setPlainText( vitem->content() );
     mUi->mKeySequenceWidget->setKeySequence( vitem->shortcut(),
                                              KKeySequenceWidget::NoValidate );
     CustomTemplates::Type type =  vitem->customType();
@@ -416,7 +417,7 @@ void CustomTemplates::slotListSelectionChanged()
     mUi->mKeySequenceWidget->setEnabled( type != TUniversal );
   } else {
     mUi->mEditFrame->setEnabled( false );
-    mUi->mEdit->clear();
+    mUi->mEdit->editor()->clear();
     // see above
     mUi->mKeySequenceWidget->clearKeySequence();
     mUi->mType->setCurrentIndex( 0 );
